<?
/**
* Mysql 服务器配置文件
*/
		@$mysql__host = JIEQI_DB_HOST;//数据库服务器
		@$mysql__user = JIEQI_DB_USER;//数据库用户名
		@$mysql__pass =	JIEQI_DB_PASS;//数据库密码
		@$mysql__db = JIEQI_DB_NAME;//数据库名
/**
* Mysql 操作类
*/
class hon6mysql{
				function __construct(){
				    global $queries;
				    global $querysqls;
				    $GLOBALS['queries'] = 0;
				    $GLOBALS['querysqls'] = "";
				}
        function mysql_link(){ //建立连接
                global $mysql__host,$mysql__user,$mysql__pass,$mysql__db;
                $link = @mysql_connect($mysql__host,$mysql__user,$mysql__pass) or die ('连接MYSQL服务器出错');
                @mysql_select_db($mysql__db,$link) or die ('连接MYSQL数据库出错');
                return $link;
        }
        function query($sql){ //执行 SQL 语句
        				mysql_query('set names gbk'); //此句在你的mysql字符集为latin1时不需要 注释即可
                mysql_query('set character_set_client = utf8');
								mysql_query('set character_set_connection = utf8');
								mysql_query('set character_set_results = utf8');
                $sqlresult = @mysql_query($sql) or die ('SQL ERROR:('.$sql.")".mysql_error());
                ++$GLOBALS['queries'];
                $GLOBALS['querysqls'] .= $sql."<br/>";
                return $sqlresult;
        }
        function num_rows($sql){ //获得记录总数
                $num = @mysql_num_rows($sql);
                return $num;
        }
        function fetch_object($sql){ //返回一条记录
        				return @mysql_fetch_object($sql);
        }
        function fetch_array($sql, $type = MYSQL_ASSOC){ //查询多条记录
                return mysql_fetch_array($sql,$type);
        }
        function fetch_assoc($sql){ //查询多条记录
                return @mysql_fetch_assoc($sql);
        }
        function fetch_row($sql){ //查询多条记录
                return @mysql_fetch_row($sql);
        }
        function insert_id(){ //取得上一步 INSERT 操作产生的 ID
                return @mysql_insert_id();
        }
        function free_result($sql){ //释放资源
                return @mysql_free_result($sql);
        }
        function list_tables(){ //获得数据表
        				global $mysql__db;
                return $this->query_array("SHOW TABLES FROM $mysql__db");
        }
        function close(){ //关闭MYSQL连接
                return @mysql_close();
        }
        /******************************  以上是基本操作 以下是此mysql操作类的精华部分 *************************/
        function query_num($sql){ //查询总数
                $sql = $this->query($sql);
                $num = @mysql_num_rows($sql);
                $num = $num?$num:0;
                return $num;
        }
        function query_array($sql){ //查询多条记录保存到数组
                $sql = $this->query($sql);
                $num = @mysql_num_rows($sql);
                if($num){
                        $array = array();
                        for($a=0; $row = @mysql_fetch_array($sql); $a++){
                                $array[$a] = $row;
                        }
                        return $array;
                }else{
                        return false;
                }
        }
        function query_object($sql){ //查询一条记录保存到数组
                $sql = $this->query($sql);
                $num = @mysql_num_rows($sql);
                if($num){
                        $array = array();
                        $array = @mysql_fetch_object($sql);
                        return $array;
                }else{
                        return false;
                }
        }
        function query_field($sql){ //返回一条记录中一个字段
                $sql = $this->query($sql);
                $row = @mysql_fetch_row($sql);
                if($row){
                 		return $row[0];
                }else{
                		return false;
                }
        }
}
?>